from .template import Template


class Provider():
    description = (
        "Provider – единица описания поставщика услуг/ответственного лица за определенный ресурс (например, машину). "
        "По сути - это надстройка к клиентскому аккаунту, иллюстрирующая, что данный пользователь может выступать не только в роли потребителя. "
        "То есть, по тому, какие “провайдеры” находятся по идентификатору пользователя - можно установить конкретный список услуг данного пользователя."
    )

    # ID METASERVICE
    id_metaservice = Template.id_metaservice

    # DATA
    type = models.CharField(
        max_length=150,
        help_text="тип поставщика (партнер/ответственное лицо/поставщик услуг). Смысл такой - провайдер это статус пользователя, который, в зависимости от применения, может нести разный смысл и подразумевает под собой какой-то тип действия. Обычные исполнители - это провайдеры услуг (код 3). Ответственные за какое-то имущество, которые сдают его в аренду - это тоже провайдеры (код 2). Ответственные за набор услуг перед метасервисом (фактически - назначенные админы) - это провайдеры-партнеры (код 1)"
    )
    requirements = models.CharField(
        max_length=300,
        help_text="требования для того, чтобы можно было предоставлять услуги любые в этом метасервисе в целом (самые строгие)"
    )
    status = models.CharField(
        max_length=150,
        help_text="статус пользователя в системе относительно прохождения проверок (activity_status) (может быть active только в том случае, если ticket, влияющий на статус - закрыт."
    )
    location_type = models.CharField(
        max_length=300,
        help_text="статическая или динамическая локация оказания услуги. Если статическая, а исполнитель находится существенно за пределами локации - то тогда статус автоматом оффлайн для приема новых заявок."
    )
    default_location = models.CharField(
        max_length=300,
        help_text="локация по умолчанию для объекта."
    )

    # OTHER
    is_global = Template.is_global
    is_visible = Template.is_visible

    # FK
    user_id = models.ForeignKey(
        get_user_model(),
        on_delete=models.DO_NOTHING,
        null=True,
        help_text="уникальный идентификатор конкретного пользователя системы (meta-user), который будет оказывать услугу. Один пользователь может быть провайдером нескольких услуг. Статус провайдера означает, что с данным пользователем может быть установлена связь, как с исполнителем."
    )
    company_id = models.ForeignKey(
        Company,
        on_delete=models.DO_NOTHING,
        null=True,
        help_text="уникальный идентификатор компании, от лица которой выступает провайдер. Смысл такой - ответственны могут быть только одушевленные лица, компании - не одушевленные. Все услуги предоставляются через компании-партнеры, самозанятые или ИП являются единицами таких компаний."
    )
    ticket_status = models.ForeignKey(
        Ticket,
        on_delete=models.DO_NOTHING,
        null=True,
        help_text="id последнего актуального тикета, касающийся статуса. Если он меняет статус на закрытый - вызывается проверка, которая смотрит, нет ли другого открытого по пользователю."
    )
    service = models.ForeignKey(
        Service,
        on_delete=models.DO_NOTHING,
        null=True,
        help_text="id услуги, которую предостовляют"
    )
