from django.contrib.auth import get_user_model
from django.db import models

from tickets.models import Ticket


class Permissions(models.Model):
    """
    Разрешения - (проверки/экзамены). 
    По смыслу это что-то вроде “документа на право что-то делать” - на данном этапе это ограничено метасервисом/платформой, 
    при этом он может быть полностью цифровым (выданным платформой/сервисом).
    """

    id = models.IntegerField(
        primary_key=True
    )

    # ID METASERVICE
    id_metaservice = models.PositiveIntegerField(
        help_text=" уникальный идентификатор мета-сервиса, необходимый для синхронизации данных."
    )

    # DATA
    permission_type = models.BigIntegerField(
        help_text="уникальный идентификатор определяющий наличие разрешения из множества в словаре - выданных пользователю/клиенту/аккаунту"
    )
    check_level = models.CharField(
        max_length=10,
        help_text="(check-level из классификатора платформы) - информация об уровне проверки. Проверка может быть проведена как платформой, так и мета-сервисом, так и партнером мета-сервиса, а может быть и никем (просто загружен). Указывается, так как достоверность проверки разная. Экзамен, проверенный только на низком уровне, не принимается во внимание как имеющийся до прохождения более высокоуровневой проверки."
    )
    status = models.CharField(
        max_length=150,
        help_text="статус обработки заявки в системе заявок"
    )
    check_date = models.DateTimeField(
        null=True,
        help_text="timestamp проверки"
    )
    expire_date = models.DateField(
        help_text="Срок окончания действия разрешения"
    )

    # OTHER
    is_global = models.CharField(
        max_length=1,
        default="f",
        help_text="доступна ли информация для хранения в глобальном сервисе/нужна синхронизация"
    )
    is_visible = models.CharField(
        max_length=1,
        default="f",
        help_text="доступна ли информация о наличии разрешения для планирования в цепочке с другими услугами в глобальном сервисе"
    )

    # FK
    ticket_status = models.ForeignKey(
        Ticket,
        on_delete=models.DO_NOTHING,
        null=True,
        help_text="id заявки, по которой происходит проверка статуса relationship. State меняется только в результате изменений в заявке."
    )
    user_id = models.ForeignKey(
        get_user_model(),
        related_name="user_id_perm",
        on_delete=models.DO_NOTHING,
        null=True,
        help_text="уникальный идентификатор пользователя/клиента/аккаунта, которым была пройдена проверка и получено разрешение"
    )
    checked_by = models.ForeignKey(
        get_user_model(),
        related_name="checked_by_perm",
        on_delete=models.DO_NOTHING,
        null=True,
        help_text="userid проверившего"
    )

    class Meta:
        db_table = "permissions"
        verbose_name = "Разрешение"
        verbose_name_plural = "Разрешения"
