from django.contrib.auth import get_user_model
from django.db import models

from tickets.models import Ticket


class Resource(models.Model):
    """
    Resource/Список ресурсов – автомобили/дома/объекты сервиса
    """

    id = models.IntegerField(
        primary_key=True
    )

    # ID METASERVICE
    id_metaservice = models.PositiveIntegerField(
        null=True,
        help_text="уникальный идентификатор мета-сервиса, необходимый для синхронизации данных. Один и тот же провайдер может быть для нескольких мета-сервисов, соответственно если происходят изменения в одном, то либо форсируется изменение во всех (если возможно), либо снимается is_global. Соответственно при изменении is_global в true должно происходить согласование с остальными копиями в других сервисах. Нужен в том числе для того, чтобы выяснять, в каких еще сервисах есть этот провайдер."
    )

    # DATA
    resoure_type = models.CharField(
        max_length=10,
        help_text="определение типа ресурса по его уникальному идентификатору в соответствии с классификатором"
    )
    requirements = models.CharField(
        max_length=150,
        help_text="код необходимого (самый строгий) для того, чтобы ресурс мог стать активным"
    )
    status = models.CharField(
        max_length=150,
        help_text="статус ресурса в системе относительно прохождения проверок (activity_status) (может быть active только в том случае, если ticket, влияющий на статус - закрыт."
    )

    # OTHER
    is_global = models.CharField(
        max_length=1,
        default="f",
        help_text="доступны ли данные (по услугам или ресурсам?) для хранения в глобальном сервисе/необходима синхронизация"
    )
    is_visible = models.CharField(
        max_length=1,
        default="f",
        help_text="доступно ли для планирования в цепочке с другими услугами в глобальном сервисе"
    )

    # FK
    ticket_status = models.ForeignKey(
        Ticket,
        on_delete=models.DO_NOTHING,
        help_text="id последнего актуального тикета, касающийся статуса. Если он меняет статус на закрытый - вызывается проверка, которая смотрит, нет ли другого открытого по пользователю."
    )
    user_id = models.ForeignKey(
        get_user_model(),
        on_delete=models.DO_NOTHING,
        help_text="уникальный идентификатор ответственного (за состояние, доступность и так далее - то есть для договора) пользователя - идентификатор провайдера, по которому восстанавливается конкретный пользовательский аккаунт"
    )

    class Meta:
        db_table = "resource"
        verbose_name = "Ресурс"
        verbose_name_plural = "Ресурсы"
